==> eiffelstudio-19.05.10.3187.tar: F_code/C10/xm481.c <==
/*
 * Code for class XML_FILE_INPUT_STREAM
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm481.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XML_FILE_INPUT_STREAM}.make */
void F1039_8466 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = F777_6156(RTCW(arg1));
	tr1 = F1048_8863(RTCW(tr1));
	F1039_8470(Current, tr1);
	tr1 = RTLNSMART(eif_new_type(1028, 1).id);
	F1024_7897(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4096L);
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5399[Dtype(RTCW(arg1))-749])(arg1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.name */
EIF_REFERENCE F1039_8469 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XML_FILE_INPUT_STREAM}.set_name */
void F1039_8470 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
}

/* {XML_FILE_INPUT_STREAM}.end_of_input */
EIF_BOOLEAN F1039_8473 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_INTEGER_32 ti4_5;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	Result = *(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_);
	ti4_3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_);
	ti4_4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_);
	ti4_5 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (Result && ((EIF_BOOLEAN) ((EIF_BOOLEAN) (ti4_1 > ti4_2) && (EIF_BOOLEAN) ((EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_3 - ti4_4) + ((EIF_INTEGER_32) 1L)) < ti4_5))));
	return Result;
}

/* {XML_FILE_INPUT_STREAM}.index */
EIF_INTEGER_32 F1039_8475 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
}


/* {XML_FILE_INPUT_STREAM}.line */
EIF_INTEGER_32 F1039_8476 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_);
}


/* {XML_FILE_INPUT_STREAM}.column */
EIF_INTEGER_32 F1039_8477 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_);
}


/* {XML_FILE_INPUT_STREAM}.last_character */
EIF_CHARACTER_8 F1039_8478 (EIF_REFERENCE Current)
{
	return *(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_);
}


/* {XML_FILE_INPUT_STREAM}.compute_smart_chunk_size */
void F1039_8481 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN) (arg1 > ((EIF_INTEGER_32) 0L))) {
		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 100L));
	} else {
		loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_0_);
		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 / ((EIF_INTEGER_32) 100L));
	}
	if ((EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_))) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_);
		ti4_1 = eif_max_int32 (ti4_1,(EIF_INTEGER_32) (loc1 - (EIF_INTEGER_32) (loc1 % ((EIF_INTEGER_32) 4096L))));
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) ti4_1;
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (arg2 > ((EIF_INTEGER_32) 0L)) && (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) > arg2))) {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) arg2;
		}
	}
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.start */
void F1039_8482 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tb1 = '\0';
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_3_2_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tb2 = F777_6206(RTCW(tr1));
		tb1 = (EIF_BOOLEAN) !tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5473[Dtype(RTCW(tr1))-777])(tr1);
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F777_6234(RTCW(tr1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	F1039_8486(Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.close */
void F1039_8483 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	tr1 = RTLNSMART(eif_new_type(1028, 1).id);
	F1024_7897(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_3_2_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F777_6233(RTCW(tr1));
	}
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.read_character */
void F1039_8484 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_8 loc1 = (EIF_CHARACTER_8) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_))++;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_)) {
		F1039_8482(Current);
	}
	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) <= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_))) {
		loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_);
		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + loc2) - ti4_1);
		tr1 = *(EIF_REFERENCE *)(Current);
		tb1 = F1024_7909(RTCW(tr1), loc2);
		if (tb1) {
			tr1 = *(EIF_REFERENCE *)(Current);
			loc1 = F1029_8103(RTCW(tr1), loc2);
		} else {
			loc1 = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
		}
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) == *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_))) {
			F1039_8486(Current);
		}
		if ((EIF_BOOLEAN)(*(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_) == (EIF_CHARACTER_8) '\012')) {
			(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_))++;
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		} else {
			(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_))++;
		}
	} else {
		loc1 = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
	}
	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_) = (EIF_CHARACTER_8) loc1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.get_next_chunk */
void F1039_8486 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5468[Dtype(RTCW(tr1))-777])(tr1);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R4944[Dtype(RTCW(tr1))-777])(tr1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O4878[Dtype(tr1)-423]);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNSMART(eif_new_type(1028, 1).id);
		F1024_7897(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) + ((EIF_INTEGER_32) 1L));
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_) = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) + ti4_1) - ((EIF_INTEGER_32) 1L));
	RTLE;
}

void EIF_Minit481 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-23.09.10.7341.tar: F_code/C10/xm481.c <==
/*
 * Code for class XML_FILE_INPUT_STREAM
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm481.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XML_FILE_INPUT_STREAM}.make */
void F1060_8564 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = F788_6043(RTCW(arg1));
	tr1 = F1070_8972(RTCW(tr1));
	F1060_8568(Current, tr1);
	tr1 = RTLNSMART(eif_new_type(1048, 1).id);
	F1044_7972(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4096L);
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5286[Dtype(RTCW(arg1))-760])(arg1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.name */
EIF_REFERENCE F1060_8567 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XML_FILE_INPUT_STREAM}.set_name */
void F1060_8568 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
}

/* {XML_FILE_INPUT_STREAM}.end_of_input */
EIF_BOOLEAN F1060_8571 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_) && (EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_)) && (EIF_BOOLEAN) ((EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_)) + ((EIF_INTEGER_32) 1L)) < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_))));
}

/* {XML_FILE_INPUT_STREAM}.index */
EIF_INTEGER_32 F1060_8573 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
}


/* {XML_FILE_INPUT_STREAM}.line */
EIF_INTEGER_32 F1060_8574 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_);
}


/* {XML_FILE_INPUT_STREAM}.column */
EIF_INTEGER_32 F1060_8575 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_);
}


/* {XML_FILE_INPUT_STREAM}.last_character */
EIF_CHARACTER_8 F1060_8576 (EIF_REFERENCE Current)
{
	return *(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_);
}


/* {XML_FILE_INPUT_STREAM}.compute_smart_chunk_size */
void F1060_8579 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN) (arg1 > ((EIF_INTEGER_32) 0L))) {
		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 100L));
	} else {
		loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_0_);
		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 / ((EIF_INTEGER_32) 100L));
	}
	if ((EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_))) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_);
		ti4_1 = eif_max_int32 (ti4_1,(EIF_INTEGER_32) (loc1 - (EIF_INTEGER_32) (loc1 % ((EIF_INTEGER_32) 4096L))));
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) ti4_1;
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (arg2 > ((EIF_INTEGER_32) 0L)) && (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) > arg2))) {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) arg2;
		}
	}
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.start */
void F1060_8580 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tb1 = '\0';
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_3_2_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tb2 = F788_6093(RTCW(tr1));
		tb1 = (EIF_BOOLEAN) !tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5360[Dtype(RTCW(tr1))-788])(tr1);
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F788_6121(RTCW(tr1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	F1060_8584(Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.close */
void F1060_8581 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	tr1 = RTLNSMART(eif_new_type(1048, 1).id);
	F1044_7972(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_3_2_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F788_6120(RTCW(tr1));
	}
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.read_character */
void F1060_8582 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_8 loc1 = (EIF_CHARACTER_8) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_))++;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_)) {
		F1060_8580(Current);
	}
	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) <= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_))) {
		loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_);
		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + loc2) - ti4_1);
		tr1 = *(EIF_REFERENCE *)(Current);
		tb1 = F1044_7984(RTCW(tr1), loc2);
		if (tb1) {
			tr1 = *(EIF_REFERENCE *)(Current);
			loc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R5520[Dtype(RTCW(tr1))-811])(tr1, loc2));
		} else {
			loc1 = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
		}
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) == *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_))) {
			F1060_8584(Current);
		}
		if ((EIF_BOOLEAN)(*(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_) == (EIF_CHARACTER_8) '\012')) {
			(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_))++;
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		} else {
			(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_))++;
		}
	} else {
		loc1 = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
	}
	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_) = (EIF_CHARACTER_8) loc1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.get_next_chunk */
void F1060_8584 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5355[Dtype(RTCW(tr1))-788])(tr1);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R4956[Dtype(RTCW(tr1))-788])(tr1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O4884[Dtype(tr1)-424]);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNSMART(eif_new_type(1048, 1).id);
		F1044_7972(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) + ((EIF_INTEGER_32) 1L));
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_) = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) + ti4_1) - ((EIF_INTEGER_32) 1L));
	RTLE;
}

void EIF_Minit481 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
